@@ -11,7 +11,10 @@ from cherrypy.filters.basefilter import BaseFilter
 try:
     import sqlalchemy, sqlalchemy.orm
     from sqlalchemy import MetaData
-    from sqlalchemy.exceptions import ArgumentError, OperationalError
+    try:
+        from sqlalchemy.exc import ArgumentError, OperationalError
+    except ImportError: # SQLAlchemy < 0.5
+        from sqlalchemy.exceptions import ArgumentError, OperationalError
 except ImportError:
     sqlalchemy = None
 
@@ -109,12 +112,15 @@ if sqlalchemy:
     # template for an example.
     def create_session_mapper(scoped_session=session):
         def mapper(cls, *args, **kw):
+            set_kwargs_on_init = kw.pop('set_kwargs_on_init', True)
             validate = kw.pop('validate', False)
             # we accept 'save_on_init' as an alias for 'autoadd' for backward
             # compatibility, but 'autoadd' is shorter and more to the point.
             autoadd = kw.pop('autoadd', kw.pop('save_on_init', True))
 
-            if cls.__init__ is object.__init__ or cls.__init__._session_mapper:
+            if set_kwargs_on_init and (getattr(cls,
+                        '__init__', object.__init__) is object.__init__
+                    or getattr(cls.__init__, '_session_mapper', False)):
                 def __init__(self, **kwargs):
                     for key, value in kwargs.items():
                         if validate:
@@ -550,7 +556,8 @@ class EndTransactionsFilter(BaseFilter):
                 session.expunge_all()
             except AttributeError: # SQLAlchemy < 0.5.1
                 session.clear()
-        end_all()
+        else:
+            end_all()
 
 __all__ = ["AutoConnectHub", "bind_metadata", "create_session",
            "create_session_mapper", "commit_all", "end_all",
