@@ -1,5 +1,9 @@
 try:
-    from sqlobject import *
+
+    from datetime import datetime
+
+    from sqlobject import (SQLObject, ForeignKey, MultipleJoin,
+        DateTimeCol, StringCol, UnicodeCol)
 
     from turbogears.database import PackageHub
 
@@ -9,25 +13,29 @@ except ImportError:
 
 else:
 
-    from datetime import *
-
-    hub = PackageHub("turbogears.i18n.sogettext")
+    hub = PackageHub('turbogears.i18n.sogettext')
     __connection__ = hub
 
+
     class TG_Domain(SQLObject):
 
-        name = StringCol(alternateID=True)
-        messages = MultipleJoin("TG_Message")
-
         class sqlmeta:
-            table = "tg_i18n_domain"
-            defaultOrder = "name"
+            table = 'tg_i18n_domain'
+            defaultOrder = 'name'
+
+        name = StringCol(alternateID=True)
+        messages = MultipleJoin('TG_Message')
+
 
     class TG_Message(SQLObject):
 
+        class sqlmeta:
+            table = 'tg_i18n_message'
+            defaultOrder = 'name'
+
         name = UnicodeCol()
-        text = UnicodeCol(default="")
-        domain = ForeignKey("TG_Domain")
+        text = UnicodeCol(default='')
+        domain = ForeignKey('TG_Domain')
         locale = StringCol(length=15)
         created = DateTimeCol(default=datetime.now)
         updated = DateTimeCol(default=None)
@@ -37,6 +45,3 @@ else:
             self._SO_set_text(text)
             self.updated = datetime.now()
 
-        class sqlmeta:
-            table = "tg_i18n_message"
-            defaultOrder = "name"
