@@ -1,10 +1,12 @@
 # coding=UTF-8
-import re
+
 import unittest
 import urllib
 import base64
+
 import formencode
 import cherrypy
+
 from turbogears import testutil, database, identity, config, startup, expose
 from turbogears.controllers import Controller, RootController
 from turbogears.identity import (SecureObject, SecureResource,
@@ -17,8 +19,8 @@ from turbogears.identity.exceptions import (IdentityConfigurationException,
     RequestRequiredException)
 from turbogears.identity.visitor import IdentityVisitPlugin
 
-#hub = database.AutoConnectHub("sqlite:///:memory:")
-hub = database.PackageHub("turbogears.identity")
+# hub = database.AutoConnectHub("sqlite:///:memory:")
+hub = database.PackageHub('turbogears.identity')
 
 
 def mycustomencrypt(password):
@@ -125,6 +127,18 @@ class TestSecureObject(unittest.TestCase):
         test_object._cp_filters = test_filters
         assert test_object._cp_filters == test_filters
 
+    def test_secure_object_proxies_setattr(self):
+        """Test that SecureObject also proxies attributes assigned later."""
+
+        class TestObject(object):
+            pass
+
+        test_object = SecureObject(TestObject(), None)
+        assert isinstance(test_object._object, TestObject)
+
+        test_object.value = 'value'
+        assert test_object._object.value == 'value'
+
 
 class RestrictedArea(Controller, SecureResource):
 
@@ -297,9 +311,10 @@ class TestIdentity(testutil.TGTest):
             'visit.on': True, 'identity.on': True,
             'visit.manager': 'sqlalchemy',
             'identity.failure_url': '/identity_failed',
+            'identity.force_external_redirect': False,
             'identity.soprovider.encryption_algorithm': None,
-            'identity.http_basic_auth': False,
-            'identity.http_auth_realm': None,
+            'identity.http_basic_auth': True,
+            'identity.http_auth_realm': 'test realm',
             'tg.strict_parameters': True,
             'tg.allow_json': False}}
         if not self.config:
@@ -310,6 +325,7 @@ class TestIdentity(testutil.TGTest):
         config.configure_loggers(test_config)
         config.update(test_config['global'])
         super(TestIdentity, self).setUp()
+        config.update({'identity.http_basic_auth': False})
         self.init_model()
 
     def init_model(self):
@@ -483,27 +499,50 @@ class TestIdentity(testutil.TGTest):
             'user_name=samIam&password=secret&login=Login')
         assert 'logged_in_only' in response, response
 
+    def test_external_redirect(self):
+        """Test that external redirection at identity failures works."""
+        config.update({'identity.failure_url': 'test_login',
+            'identity.force_external_redirect': True})
+        response = self.app.get('/logged_in_only?a=1&b=2', status=302)
+        assert 'identity_failed_answer' not in response, response
+        path, params = response.headers['Location'].split('?', 1)
+        assert path.endswith('/test_login')
+        params = '&'.join(sorted(params.split('&')))
+        assert params == 'a=1&b=2&forward_url=%2Flogged_in_only'
+
+    def test_external_redirect_with_funky_params(self):
+        """Test that external redirection properly handles funky parameters."""
+        config.update({'identity.force_external_redirect': True})
+        response = self.app.get('/logged_in_only?'
+            'a-0.x=1&a-0.y=2&a-1.x=3&a-1.y=4', status=302)
+        assert 'identity_failed_answer' not in response, response
+        path, params = response.headers['Location'].split('?', 1)
+        assert path.endswith('/identity_failed')
+        params = '&'.join(sorted(params.split('&')))
+        assert params == ('a-0.x=1&a-0.y=2&a-1.x=3&a-1.y=4'
+            '&forward_url=%2Flogged_in_only')
+
     def test_authenticate_header(self):
         """Test that identity returns correct WWW-Authenticate header."""
         response = self.app.get('/logged_in_only', status=403)
         assert 'WWW-Authenticate' not in response.headers
-        config.update({'identity.http_basic_auth': True,
-                       'identity.http_auth_realm': 'test realm'})
+        config.update({'identity.http_basic_auth': True})
         response = self.app.get('/logged_in_only', status=401)
         assert response.headers['WWW-Authenticate'] == 'Basic realm="test realm"'
 
     def test_basic_authentication(self):
         """Test HTTP basic authentication mechanism."""
+        config.update({'identity.http_basic_auth': True})
         credentials = base64.encodestring('samIam')[:-1]
         response = self.app.get('/logged_in_only', headers={
-            'Authorization': 'Basic %s' % credentials}, status=403)
+            'Authorization': 'Basic %s' % credentials}, status=401)
         assert 'identity_failed_answer' in response, response
         credentials = base64.encodestring('samIam:secret:appendix')[:-1]
         response = self.app.get('/logged_in_only', headers={
-            'Authorization': 'Basic %s' % credentials}, status=403)
+            'Authorization': 'Basic %s' % credentials}, status=401)
         assert 'identity_failed_answer' in response, response
         response = self.app.get('/logged_in_only', headers={
-            'Authorization': 'Basic samIam:secret'}, status=403)
+            'Authorization': 'Basic samIam:secret'}, status=401)
         assert 'identity_failed_answer' in response, response
         credentials = base64.encodestring('samIam:secret')[:-1]
         response = self.app.get('/logged_in_only', headers={
@@ -520,7 +559,7 @@ class TestIdentity(testutil.TGTest):
         assert response.body == 'is_anonymous'
 
     def test_require_group(self):
-        """Test that a anonymous user can not access resource protected by
+        """Test that an anonymous user can not access resource protected by
         require(in_group(...))"""
         response = self.app.get('/in_peon_group', status=403)
         assert 'identity_failed_answer' in response, response
@@ -531,24 +570,22 @@ class TestIdentity(testutil.TGTest):
         response = self.app.get('/test_exposed_require')
         assert 'require is exposed' in response, response
 
+    def test_user_and_group_properties(self):
+        """Test that the current user and group properties are set correctly."""
+        user = TG_User.by_user_name("samIam")
+        group_ids = set((TG_Group.by_group_name("peon").id,
+            TG_Group.by_group_name("other").id))
+        assert user.user_name == 'samIam'
+        assert group_ids == set((2, 3))
+
     def test_require_group_viewable(self):
         """Test that a user with proper group membership can see a restricted url."""
         response = self.app.get('/in_peon_group?'
             'user_name=samIam&password=secret&login=Login')
         assert 'in_peon_group' in response, response
-        user = TG_User.by_user_name("samIam")
-
-    def test_require_group_viewable(self):
-        """Test that the current user and group properties are set correctly."""
-        response = self.app.get('/in_peon_group?'
-            'user_name=samIam&password=secret&login=Login')
-        user = TG_User.by_user_name("samIam")
-        group_ids = set((TG_Group.by_group_name("peon").id,
-            TG_Group.by_group_name("other").id))
 
     def test_user_not_in_right_group(self):
-        """Test that a user is denied access if they aren't in the right group.
-        """
+        """Test that only users in the right group have access."""
         response = self.app.get('/in_admin_group?'
             'user_name=samIam&password=secret&login=Login', status=403)
         assert 'identity_failed_answer' in response, response
@@ -758,6 +795,7 @@ class TestIdentityVisitPlugin(unittest.TestCase):
         test_config = {'global': {
             'visit.on': True,
             'identity.on': True,
+            'identity.http_basic_auth': True,
             'identity.source': 'form, http_auth, visit'}}
         if not self.config:
             original_config = dict()
