@@ -84,8 +84,18 @@ class IdentityVisitPlugin(object):
         # Sources for identity information and the order in which they should be
         # checked. These terms are mapped to methods by prepending
         # "identity_from_".
-        sources = [s.strip() for s in
-            get('identity.source', 'form,http_auth,visit').split(',')]
+        sources = filter(None, map(str.strip,
+            get('identity.source', 'form,http_auth,visit').split(',')))
+        if not sources:
+            raise IdentityConfigurationException(
+                "You must set some identity source (via identity.source).")
+        if 'http_auth' in sources and not get('identity.http_basic_auth'):
+            sources.remove('http_auth')
+        if 'visit' in sources and not get('visit.on'):
+            sources.remove('visit')
+        if not sources:
+            raise IdentityConfigurationException(
+                "You must activate at least one of the identity sources.")
         self.identity_sources = list()
         for s in sources:
             if s:
