@@ -2,7 +2,6 @@
 import types
 from math import ceil
 import logging
-import warnings
 
 import cherrypy
 try:
@@ -12,6 +11,12 @@ except ImportError:
 
 try:
     import sqlalchemy
+    try:
+        from sqlalchemy.exc import InvalidRequestError
+        sqlalchemy_before_0_5 = False
+    except ImportError: # SQLAlchemy < 0.5
+        from sqlalchemy.exceptions import InvalidRequestError
+        sqlalchemy_before_0_5 = True
 except ImportError:
     sqlalchemy = None
 
@@ -20,10 +25,9 @@ from turbogears.controllers import redirect
 from turbogears.decorator import weak_signature_decorator
 from turbogears.view import variable_providers
 from formencode.variabledecode import variable_encode
-from turbogears.widgets import PaginateDataGrid
 from turbogears.util import add_tg_args
 
-log = logging.getLogger("turbogears.paginate")
+log = logging.getLogger('turbogears.paginate')
 
 
 # lists of databases that lack support for OFFSET
@@ -36,7 +40,7 @@ _simulate_offset = None
 
 # these are helper classes for getting data that has no table column
 class attrwrapper:
-    """Helper class for accessing objec attributes."""
+    """Helper class for accessing object attributes."""
     def __init__(self, name):
         self.name = name
     def __call__(self, obj):
@@ -45,7 +49,7 @@ class attrwrapper:
         return obj
 
 class itemwrapper:
-    """Helper class for dicitionary access."""
+    """Helper class for dictionary access."""
     def __init__(self, name):
         self.name = name
     def __call__(self, obj):
@@ -61,7 +65,7 @@ def paginate(var_name, default_order='', limit=10,
     controller in order for the paginate decorator to be able to handle it.
     @type var_name: string
 
-    @param default_order: The column name(s) that will be used to orde
+    @param default_order: The column name(s) that will be used to order
     pagination results. Due to the way pagination is implemented specifying a
     default_order will override any result ordering performed in the controller.
     @type default_order: string or a list of strings. Any string starting with
@@ -395,17 +399,19 @@ def sort_ordering(ordering, sort_name):
         ordering.insert(0, (not index and '-' or '') + sort_name)
 
 def sqlalchemy_get_column(colname, var_data, join_props=None):
-    """Return a column from sqlalchemy var_data based on colname."""
-    try:
+    """Return a column from SQLAlchemy var_data based on colname."""
+    if sqlalchemy_before_0_5:
         mapper = var_data.mapper
-    except AttributeError: # SQLALchemy >= 0.5
+    else:
         mapper = var_data._mapper_zero()
     propnames = colname.split('.')
     colname = propnames.pop()
     props = []
     for propname in propnames:
-        prop = mapper.get_property(
-            propname, resolve_synonyms=True, raiseerr=False)
+        try:
+            prop = mapper.get_property(propname)
+        except InvalidRequestError:
+            prop = None
         if not prop:
             break
         if join_props is not None:
@@ -417,7 +423,7 @@ def sqlalchemy_get_column(colname, var_data, join_props=None):
     return col
 
 def sqlobject_get_column(colname, var_data, join_props=None):
-    """Return a column from sqlobject var_data based on colname."""
+    """Return a column from SQLObject var_data based on colname."""
     return getattr(var_data.sourceClass.q, colname, None)
 
 def sql_get_column(colname, var_data):
@@ -435,14 +441,14 @@ def sql_get_column(colname, var_data):
     raise TypeError('Cannot find columns of paginate variable')
 
 def sqlalchemy_order_col(col, descending=False):
-    """Return an sqlalchemy ordered column for col."""
+    """Return an SQLAlchemy ordered column for col."""
     if descending:
         return sqlalchemy.sql.desc(col)
     else:
         return sqlalchemy.sql.asc(col)
 
 def sqlobject_order_col(col, descending=False):
-    """Return an sqlobject ordered column for col."""
+    """Return an SQLObject ordered column for col."""
     if descending:
         return sqlobject.DESC(col)
     else:
@@ -453,7 +459,7 @@ def sql_order_col(col, ascending=True):
     if sqlalchemy and isinstance(col, sqlalchemy.sql.ColumnElement):
         return sqlalchemy_order_col(col, ascending)
     elif sqlobject and isinstance(col, types.InstanceType):
-        # Sadly, there is no better way to check for sqlobject col type
+        # Sadly, there is no better way to check for SQLObject col type
         return sqlobject_order_col(col, ascending)
     raise TypeError("Expected Column, but got %s" % type(col))
 
@@ -471,7 +477,10 @@ def sqlalchemy_join_props(var_data, join_props):
                     pass
         if attrs:
             log.debug("paginate: need to join some attributes")
-            var_data = var_data.outerjoin(*attrs)
+            if sqlalchemy_before_0_5: # old version, gets single argument
+                var_data = var_data.outerjoin(attrs)
+            else:
+                var_data = var_data.outerjoin(*attrs)
     return var_data
 
 def sort_data(data, ordering, in_memory=True):
@@ -483,7 +492,7 @@ def sort_data(data, ordering, in_memory=True):
     """
     try:
         order_by = data.order_by # SQLAlchemy, gets variable argument list
-        if hasattr(data, 'get_by'): # SQLAlchemy < 0.5
+        if sqlalchemy_before_0_5:
             old_order_by = order_by # old version, gets single argument
             order_by = lambda *cols: old_order_by(cols)
         get_column, order_col = sqlalchemy_get_column, sqlalchemy_order_col
