@@ -1,10 +1,11 @@
 """Graphical user interface for managing TurboGears projects"""
 
 import pkg_resources
+
 import cherrypy
-import turbogears
-from turbogears.util import get_project_name, setlike
+
 from turbogears import controllers, expose
+from turbogears.util import get_project_name, setlike
 
 
 class Info(controllers.Controller):
@@ -23,10 +24,10 @@ class Info(controllers.Controller):
 
     icon = "/tg_static/images/info.png"
 
-    [expose(template='turbogears.toolbox.info')]
+    @expose(template='turbogears.toolbox.info')
     def index(self):
         from turbogears.command.info import retrieve_info
-        packages, plugins = retrieve_info()
+        packages, plugins = retrieve_info(with_links=True)
         return dict(packages=packages, plugins=plugins)
 
 
@@ -48,7 +49,15 @@ class WidgetBrowser(controllers.Controller):
     all_descs = None
     icon = "/tg_static/images/widgets.png"
 
-    [expose(template="turbogears.toolbox.widgets")]
+    def __init__(self):
+        try:
+            import turbokid
+        except ImportError:
+            raise ImportError("Widgets need TurboKid to work.")
+
+    # We use a Kid page template here since the Widget browser
+    # needs Kid anyway to display the widgets (will be fixed in TG 1.5).
+    @expose(template="kid:turbogears.toolbox.widgets")
     def index(self, name=None):
         from turbogears import widgets
         from turbogears.widgets import js_location, Tabber, SyntaxHighlighter
@@ -58,12 +67,11 @@ class WidgetBrowser(controllers.Controller):
             all_descs = dict()
             for widgetdesc in widgets.all_widgets:
                 wd = widgetdesc()
-                all_descs[wd.full_class_name.replace(".", "_")] = wd
+                all_descs[wd.full_class_name.replace('.', '_')] = wd
             self.all_descs = all_descs
         if name:
             all_descs = {name: all_descs[name]}
-        desclist = all_descs.values()
-        desclist.sort(cmp=lambda x, y: cmp(x.name.lower(), y.name.lower()))
+        desclist = sorted(all_descs.itervalues(), key=lambda x: x.name.lower())
         output = dict(descs=desclist, viewing_one=name != None)
         if name:
             # do not extend desclist!
@@ -71,23 +79,19 @@ class WidgetBrowser(controllers.Controller):
 
         css = setlike()
         js = dict()
-        for l in js_location:
-            js[l] = setlike()
+        for location in js_location:
+            js[location] = setlike()
 
         for widgetdesc in desclist:
             if not name and widgetdesc.show_separately:
                 continue
             css.add_all(widgetdesc.retrieve_css())
+            for script in widgetdesc.retrieve_javascript():
+                js[getattr(script, 'location', js_location.head)].add(script)
 
-            for l in js_location:
-                for script in widgetdesc.retrieve_javascript():
-                    if hasattr(script, "location"):
-                        js[script.location].add(script)
-                    else:
-                        js[js_location.head].add(script)
-        output["widget_css"] = css
-        for l in js_location:
-            output["widget_js_%s" % str(l)] = js[l]
+        output['widget_css'] = css
+        for location in js:
+            output['widget_js_%s' % str(location)] = js[location]
 
         return output
 
@@ -139,7 +143,7 @@ class Toolbox(controllers.RootController):
     def arrange_in_pairs(self, tools):
         p = [[], []]
         for idx, tool in enumerate(tools):
-            p[idx%2].append(tool)
+            p[idx % 2].append(tool)
         pairs = zip(p[0], p[1])
         if len(p[0]) > len(p[1]):
             pairs.append([p[0][-1], None])
@@ -147,12 +151,12 @@ class Toolbox(controllers.RootController):
             pairs.append([p[1][-1], None])
         return pairs
 
-    [expose(template="turbogears.toolbox.main")]
+    @expose(template="turbogears.toolbox.main")
     def index(self):
         return dict(toolbox = self.arrange_in_pairs(self.toolbox),
             project = get_project_name())
 
-    [expose()]
+    @expose()
     def noaccess(self):
         return """<h3>No access for %s</h3>
             <p>
