@@ -11,7 +11,7 @@ import struct
 from inspect import getargspec, getargvalues
 from itertools import izip, islice, chain
 from operator import isSequenceType
-from urllib import quote, unquote
+from Cookie import _quote as quote_cookie, _unquote as unquote_cookie
 
 import pkg_resources
 
@@ -24,25 +24,25 @@ from turbogears import config
 def deprecated(message=None):
     """Decorator which can be used to mark functions as deprecated.
 
-    It will result in a warning being emmitted when the function is used.
+    It will result in a warning being emitted when the function is used.
 
     Inspired by http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/391367
 
     """
     def decorate(func):
         if not decorate.message:
-            decorate.message = \
-                "Call to deprecated function %s." % func.__name__
-        def newFunc(*args, **kwargs):
+            decorate.message = ("Call to deprecated function %s."
+                % func.__name__)
+        def new_func(*args, **kwargs):
             if not decorate.warned:
                 warnings.warn(decorate.message, category=DeprecationWarning,
-                    stacklevel = 2)
+                    stacklevel=2)
                 decorate.warned = True
             return func(*args, **kwargs)
-        newFunc.__name__ = func.__name__
-        newFunc.__doc__ = func.__doc__
-        newFunc.__dict__.update(func.__dict__)
-        return newFunc
+        new_func.__name__ = func.__name__
+        new_func.__doc__ = func.__doc__
+        new_func.__dict__.update(func.__dict__)
+        return new_func
     decorate.message = message
     decorate.warned = False
     return decorate
@@ -443,6 +443,45 @@ def flatten_sequence(seq):
             yield item
 
 
+def pop_from_nested_dict(params, keys):
+    """Pop a value from a nested parameter dictionary.
+
+    You must pass a list or dotted key as the key chain to the value.
+    If a value for this key chain is found, it will be removed and
+    the value will be returned. If this creates empty subkeys,
+    these will also be removed. If no single value is associated
+    with the key chain, then None will be returned.
+
+    """
+    if not isinstance(keys, list):
+        keys = keys.split('.')
+    values = []
+    for key in keys:
+        if not isinstance(params, dict) or key not in params:
+            return None
+        values.append(params)
+        params = params[key]
+    if isinstance(params, dict):
+        if None in params:
+            value = params.pop(None)
+            if params:
+                return value
+        else:
+            return None
+    else:
+        value = params
+    for key, params in reversed(zip(keys, values)):
+        del params[key]
+        if params:
+            break
+    return value
+
+
+def pop_request_params(keys):
+    """Pop a value from the nested request parameter dictionary."""
+    return pop_from_nested_dict(request.params, keys)
+
+
 def load_class(dottedpath):
     """Load a class from a module in dotted-path notation.
 
@@ -467,9 +506,14 @@ def load_class(dottedpath):
         # properly log the exception information and return None
         # to tell caller we did not succeed
         logging.exception('tg.utils: Could not import %s'
-            ' because exception occurred' % dottedpath)
+            ' because an exception occurred', dottedpath)
+        return None
+    try:
+        return getattr(module, classname)
+    except AttributeError:
+        logging.exception('tg.utils: Could not import %s'
+            ' because the class was not found', dottedpath)
         return None
-    return getattr(module, classname)
 
 
 def parse_http_accept_header(accept):
@@ -586,19 +630,6 @@ def to_utf8(value):
     return value
 
 
-_safe_for_cookie = ''.join(filter(lambda c: c != quote(c)
-    and c not in "$,; \t\f\n\r\v", map(chr, xrange(256))))
-
-def quote_cookie(value):
-    """Escape chars in value that should not be put directly in a cookie."""
-    return quote(value, _safe_for_cookie)
-
-
-def unquote_cookie(value):
-    """Unescape chars in a cookie value, the reverse of quote_cookie(value)."""
-    return unquote(value)
-
-
 def get_template_encoding_default(engine_name=None):
     """Return default encoding for template files (Kid, Genshi, etc.)."""
     if engine_name is None:
@@ -797,8 +828,9 @@ __all__ = ["Bunch", "DictObj", "DictWrapper", "Enum", "setlike",
            "ensure_sequence", "has_arg", "to_kw", "from_kw", "adapt_call",
            "call_on_stack", "remove_keys", "arg_index",
            "inject_arg", "inject_args", "add_tg_args", "bind_args",
-           "recursive_update", "combine_contexts",
-           "request_available", "flatten_sequence", "load_class",
+           "recursive_update", "combine_contexts", "request_available",
+           "flatten_sequence", "pop_from_nested_dict",
+           "pop_request_params", "load_class",
            "parse_http_accept_header", "simplify_http_accept_header",
            "to_unicode", "to_utf8", "quote_cookie", "unquote_cookie",
            "get_template_encoding_default", "get_mime_type_for_format",
